@@ -1517,7 +1517,7 @@ Sparse<T>::index (idx_vector& idx_arg, int resize_ok) const
 	if (idx_arg.one_zero_only ())
 	  retval = Sparse<T> (dim_vector (0, 0));
 	else
-	  retval = Sparse<T> (dim_vector (0, 1));
+	  retval = Sparse<T> (idx_orig_dims);
       else if (nz < 1)
 	if (n >= idx_orig_dims.numel ())
 	  retval = Sparse<T> (idx_orig_dims);
@@ -1537,7 +1537,7 @@ Sparse<T>::index (idx_vector& idx_arg, int resize_ok) const
 	  for (octave_idx_type i = 0; i < n; i++)
 	    {
 	      if (i % new_nr == 0)
-		retval.xcidx(i % new_nr) = ic;
+		retval.xcidx(i / new_nr) = ic;
 
 	      octave_idx_type ii = idx_arg.elem (i);
 	      if (ii == 0)
@@ -1946,10 +1946,9 @@ Sparse<T>::index (idx_vector& idx_i, idx_vector& idx_j, int resize_ok) const
 			start_nodes[ii] = i;
 		      else
 			{
-			  struct idx_node inode = nodes[node];
-			  while (inode.next)
-			    inode = *inode.next;
-			  inode.next = nodes + i;
+			  while (nodes[node].next)
+			    node = nodes[node].next->i;
+			  nodes[node].next = nodes + i;
 			}
 		    }
 
@@ -1974,8 +1973,7 @@ Sparse<T>::index (idx_vector& idx_i, idx_vector& idx_j, int resize_ok) const
 			      
 				  while (true)
 				    {
-				      if (inode.i >= 0 && 
-					  idx_i.elem (inode.i) < nc)
+				      if (idx_i.elem (inode.i) < nr)
 					new_nzmx ++;
 				      if (inode.next == 0)
 					break;
@@ -2011,8 +2009,7 @@ Sparse<T>::index (idx_vector& idx_i, idx_vector& idx_j, int resize_ok) const
 			      
 				  while (true)
 				    {
-				      if (inode.i >= 0 && 
-					  idx_i.elem (inode.i) < nc)
+				      if (idx_i.elem (inode.i) < nr)
 					{
 					  X [inode.i] = data (i);
 					  retval.xridx (kk++) = inode.i;
@@ -2162,7 +2159,7 @@ assign1 (Sparse<LT>& lhs, const Sparse<RT>& rhs)
 
 	  if (nr > 1)
 	    {
-	      Sparse<LT> tmp (max_idx, 1, new_nzmx);
+	      Sparse<LT> tmp ((max_idx > nr ? max_idx : nr), 1, new_nzmx);
 	      tmp.cidx(0) = 0;
 	      tmp.cidx(1) = new_nzmx;
 
@@ -2206,7 +2203,7 @@ assign1 (Sparse<LT>& lhs, const Sparse<RT>& rhs)
 	    }
 	  else
 	    {
-	      Sparse<LT> tmp (1, max_idx, new_nzmx);
+	      Sparse<LT> tmp (1, (max_idx > nc ? max_idx : nc), new_nzmx);
 
 	      octave_idx_type i = 0;
 	      octave_idx_type ii = 0;
@@ -2281,7 +2278,7 @@ assign1 (Sparse<LT>& lhs, const Sparse<RT>& rhs)
 
 	  if (nr > 1)
 	    {
-	      Sparse<LT> tmp (max_idx, 1, new_nzmx);
+	      Sparse<LT> tmp ((max_idx > nr ? max_idx : nr), 1, new_nzmx);
 	      tmp.cidx(0) = 0;
 	      tmp.cidx(1) = new_nzmx;
 
@@ -2324,7 +2321,7 @@ assign1 (Sparse<LT>& lhs, const Sparse<RT>& rhs)
 	    }
 	  else
 	    {
-	      Sparse<LT> tmp (1, max_idx, new_nzmx);
+	      Sparse<LT> tmp (1, (max_idx > nc ? max_idx : nc), new_nzmx);
 
 	      octave_idx_type i = 0;
 	      octave_idx_type ii = 0;
@@ -2471,11 +2468,14 @@ assign (Sparse<LT>& lhs, const Sparse<RT>& rhs)
       int idx_i_is_colon = idx_i.is_colon ();
       int idx_j_is_colon = idx_j.is_colon ();
 
-      if (idx_i_is_colon)
-	n = lhs_nr > 0 ? lhs_nr : rhs_nr;
+      if (lhs_nr == 0 && lhs_nc == 0)
+	{
+	  if (idx_i_is_colon)
+	    n = rhs_nr;
 
-      if (idx_j_is_colon)
-	m = lhs_nc > 0 ? lhs_nc : rhs_nc;
+	  if (idx_j_is_colon)
+	    m = rhs_nc;
+	}
 
       if (idx_i && idx_j)
 	{
@@ -2487,9 +2487,6 @@ assign (Sparse<LT>& lhs, const Sparse<RT>& rhs)
 	    {
 	      if (rhs_nr == 1 && rhs_nc == 1 && n >= 0 && m >= 0)
 		{
-		  // No need to do anything if either of the indices
-		  // are empty.
-
 		  if (n > 0 && m > 0)
 		    {
 		      idx_i.sort (true);
@@ -2594,6 +2591,50 @@ assign (Sparse<LT>& lhs, const Sparse<RT>& rhs)
 		      
 		      lhs = stmp;
 		    }
+		  else
+		    {
+#if 0
+		      // FIXME -- the following code will make this
+		      // function behave the same as the full matrix
+		      // case for things like
+		      //
+		      // x = sparse (ones (2));
+		      // x([],3) = 2;
+		      //
+		      // x =
+		      //
+		      // Compressed Column Sparse (rows = 2, cols = 3, nnz = 4)
+		      //
+		      // (1, 1) ->  1
+		      // (2, 1) ->  1
+		      // (1, 2) ->  1
+		      // (2, 2) ->  1
+		      //
+		      // However, Matlab doesn't resize in this case
+		      // even though it does in the full matrix case.
+
+		      if (n > 0)
+			{
+			  octave_idx_type max_row_idx = idx_i_is_colon ? 
+			    rhs_nr : idx_i.max () + 1;
+			  octave_idx_type new_nr = max_row_idx > lhs_nr ? 
+			    max_row_idx : lhs_nr;
+			  octave_idx_type new_nc = lhs_nc;
+
+			  lhs.resize (new_nr, new_nc);
+			}
+		      else if (m > 0)
+			{
+			  octave_idx_type max_col_idx = idx_j_is_colon ? 
+			    rhs_nc : idx_j.max () + 1;
+			  octave_idx_type new_nr = lhs_nr;
+			  octave_idx_type new_nc = max_col_idx > lhs_nc ? 
+			    max_col_idx : lhs_nc;
+
+			  lhs.resize  (new_nr, new_nc);
+			}
+#endif
+		    }
 		}
 	      else if (n == rhs_nr && m == rhs_nc)
 		{
