@@ -65,8 +65,9 @@
 ##
 ## @strong{Example}
 ## @example
-## octave:1> sys=ss([1 2; 3 4],[5;6],[7 8]);
-## octave:2> sys = syssetsignals(sys,"st",str2mat("Posx","Velx"));
+## octave:1> sys=ss ([1 2; 3 4],[5;6],[7 8]);
+## octave:2> sys = syssetsignals (sys, "st",
+## >                              str2mat("Posx","Velx"));
 ## octave:3> sysout(sys)
 ## Input(s)
 ##         1: u_1
@@ -95,79 +96,77 @@
 
 function retsys = syssetsignals (sys, opt, names, sig_idx)
 
-  if (nargin < 3 | nargin > 4)
+  if (nargin < 3 || nargin > 4)
     print_usage ();
-  elseif (!isstruct(sys))
-    error("sys must be a system data structure");
-  elseif (isempty(opt))
+  elseif (! isstruct (sys))
+    error ("sys must be a system data structure");
+  elseif (isempty (opt))
     opt = "out";
-  elseif( ! ischar(opt)  )
-    error("opt must be a string");
-  elseif( ! (strcmp(opt,"out") + strcmp(opt,"yd") + ...
-    strcmp(opt,"in") + strcmp(opt,"st") ) )
-    error("opt must be one of [], ""out"", ""yd"", ""in"", or ""st""");
-  elseif(nargin == 4)
-    if(is_signal_list(sig_idx) | ischar(sig_idx))
+  elseif (! ischar (opt))
+    error ("opt must be a string");
+  elseif (! (strcmp (opt, "out") || strcmp (opt, "yd")
+	     || strcmp (opt, "in") || strcmp (opt, "st")))
+    error ("opt must be one of [], \"out\", \"yd\", \"in\", or \"st\"");
+  elseif (nargin == 4)
+    if (is_signal_list (sig_idx) || ischar (sig_idx))
       ## convert to vector of indices
-      if(opt == "yd")
-        sig_idx = sysidx(sys,"out",sig_idx);
+      if (opt == "yd")
+        sig_idx = sysidx (sys, "out", sig_idx);
       else
-        sig_idx = sysidx(sys,opt,sig_idx);
+        sig_idx = sysidx (sys, opt, sig_idx);
       endif
     endif
 
     ## check index vector
-    if(min(size(sig_idx)) > 1)
-      disp("syssetsignals: sig_idx=")
-      disp(sig_idx);
-      error("sig_idx must be a vector")
+    if (min (size (sig_idx)) > 1)
+      disp ("syssetsignals: sig_idx=")
+      disp (sig_idx);
+      error ("sig_idx must be a vector")
     endif
   endif
 
-  sig_vals = sysgetsignals(sys,opt);
+  sig_vals = sysgetsignals (sys, opt);
 
   ## make sure it's in state space form if state names are given
-  if(strcmp(opt,"st"))
-    sys = sysupdate(sys,"ss");
+  if (strcmp (opt, "st"))
+    sys = sysupdate (sys, "ss");
   endif
 
-  if(strcmp(opt,"yd") == 0)
+  if (strcmp (opt, "yd") == 0)
     ## it's a signal name list we're changing
-    if(!iscell(names))
+    if (! iscell (names))
       names = {names};
     endif
-    if( (!is_signal_list(names)) & (!isempty(names)) )
-      if(ischar(names{1}))
-        warning("syssetsignals(opt=%s): converting string matrix \"names\" to a cell array of strings",opt);
+    if (! is_signal_list (names) && ! isempty (names))
+      if (ischar (names{1}))
         tmpstr = names{1};
         for ii=1:rows(tmpstr)
           names{ii} = deblank(tmpstr(ii,:));
         endfor
       else
-        names
-        error("parameter \"names\" must be a cell array of strings");
+        error ("parameter \"names\" must be a cell array of strings");
       endif
     endif
-    nsigs = length(sig_vals);
+    nsigs = length (sig_vals);
 
-    if(nargin == 3)
+    if (nargin == 3)
       ## replace all signal names
-      if(length(names) != nsigs)
-        error("opt=%s, sig_idx omitted: names(len=%d) should have %d entries ", ...
-          opt,length(names),nsigs);
+      if (length (names) != nsigs)
+        error ("opt=%s, sig_idx omitted: names(len=%d) should have %d entries ",
+               opt, length (names), nsigs);
       endif
       sig_idx = 1:nsigs;
-    elseif(length(names) != length(sig_idx))
+    elseif (length (names) != length (sig_idx))
       ## replace specified signal names
-      error("opt=%s, sig_idx(len=%d), names(len=%d) mismatch",opt, ...
-        length(sig_idx), length(names));
+      error ("opt=%s, sig_idx(len=%d), names(len=%d) mismatch",
+	     opt, length (sig_idx), length (names));
     endif
 
-    for ii=1:length(sig_idx)
+    for ii = 1:length(sig_idx)
       jj = sig_idx(ii);
-      if(jj < 1 | jj > nsigs | jj != floor(jj+0.5))
-        error("opt=%s, sig_idx(%d)=%d, %e: must be an integer between 1 and %d", ...
-          opt, ii, jj, jj, nsigs);
+      if (jj < 1 || jj > nsigs || jj != floor (jj+0.5))
+        error ("opt=%s, sig_idx(%d)=%d, %e: must be an integer between 1 and %d",
+               opt, ii, jj, jj, nsigs);
       endif
       sig_vals{jj} = names{ii};
     endfor
@@ -175,68 +174,68 @@ function retsys = syssetsignals (sys, opt, names, sig_idx)
   else
     ## update yd
     ## 1st check pathological case: no outputs
-    nout = sysdimensions(sys,"out");
-    if(nout == 0)
-      if(nargin != 3)
-        error("opt=%s, %d outputs, sysgetsignals cannot take 4 arguments", ...
-          yd,nout);
+    nout = sysdimensions (sys, "out");
+    if (nout == 0)
+      if (nargin != 3)
+        error ("opt=%s, %d outputs, sysgetsignals cannot take 4 arguments",
+               opt, nout);
       endif
-      if(!isempty(names))
-        error("opt=%s, %d outputs, names is not empty");
+      if (! isempty (names))
+        error ("opt=%s, %d outputs, names is not empty", opt, nout);
       endif
       sigvals = [];
     else
-      nsigs = length(sig_vals);
-      if(!isvector(names))
-        error("syssetsignals: opt=yd, names(%dx%d) must be a vector", ...
-          rows(names), columns(names));
+      nsigs = length (sig_vals);
+      if (! isvector (names))
+        error ("syssetsignals: opt=%s, names(%dx%d) must be a vector",
+              opt, rows (names), columns (names));
       endif
-      if(nargin == 3)
-        if(length(names) != nsigs)
-          error("opt=yd, sig_idx omitted: names(%d) should be length(%d)", ...
-            length(names), nsigs);
+      if (nargin == 3)
+        if (length (names) != nsigs)
+          error ("opt=%s, sig_idx omitted: names(%d) should be length(%d)",
+		 opt, length (names), nsigs);
         endif
         sig_idx = 1:nsigs;
-      elseif(length(names) != length(sig_idx))
-        error("opt=yd: length(names)=%d, length(sig_idx)=%d",length(names), ...
-          length(sig_idx) );
+      elseif (length(names) != length (sig_idx))
+        error ("opt=%s: length(names)=%d, length(sig_idx)=%d",
+	       opt, length (names), length (sig_idx));
       endif
 
-      badidx = find(names != 0 & names != 1);
-      if(! isempty(badidx) )
-        for ii=1:length(badidx)
-          warning("syssetsignals: opt=yd: names(%d)=%e, must be 0 or 1", ...
-            badidx(ii), names(badidx(ii)) );
+      badidx = find (names != 0 & names != 1);
+      if (! isempty (badidx))
+        for ii = 1:length(badidx)
+          warning ("syssetsignals: opt=%s: names(%d)=%e, must be 0 or 1",
+		   opt, badidx(ii), names(badidx(ii)) );
         endfor
-        error ("opt=yd: invalid values in names");
+        error ("opt=%s: invalid values in names", opt);
       endif
 
-      for ii=1:length(sig_idx)
+      for ii = 1:length(sig_idx)
         jj = sig_idx(ii);
-        if(jj < 1 | jj > nsigs | jj != floor(jj))
-          error("sig_idx(%d)=%d, %e: must be an integer between 1 and %d", ...
-            ii,jj, jj, nsigs);
+        if (jj < 1 || jj > nsigs || jj != floor (jj))
+          error ("sig_idx(%d)=%d, %e: must be an integer between 1 and %d",
+		 ii, jj, jj, nsigs);
         endif
         sig_vals(jj) = names(ii);
       endfor
-      if(any(sig_vals == 1) & sysgettsam(sys) == 0)
-        warning("Setting system sampling time to 1");
-        printf("syssetsignals: original system sampling time=0 but output(s)\n");
-        disp(find(sig_vals==1))
-        printf("are digital\n");
-        sys = syschtsam(sys,1);
+      if (any (sig_vals == 1) && sysgettsam (sys) == 0)
+        warning ("Setting system sampling time to 1");
+        printf ("syssetsignals: original system sampling time=0 but output(s)\n");
+        disp (find (sig_vals == 1))
+        printf ("are digital\n");
+        sys = syschtsam (sys, 1);
       endif
 
     endif
   endif
 
-  if(strcmp(opt,"st"))
+  if (strcmp (opt, "st"))
     sys.stname = sig_vals;
-  elseif(strcmp(opt,"in"))
+  elseif (strcmp (opt, "in"))
     sys.inname = sig_vals;
-  elseif(strcmp(opt,"out"))
+  elseif (strcmp (opt, "out"))
     sys.outname = sig_vals;
-  elseif(strcmp(opt,"yd"))
+  elseif (strcmp (opt, "yd"))
     sys.yd = sig_vals;
   endif
 
