@@ -1,13 +1,13 @@
 /*
 
-Copyright (C) 2002 John W. Eaton
+Copyright (C) 2002, 2005, 2006, 2007 John W. Eaton
 
 This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -15,9 +15,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -71,7 +70,7 @@ template void
 kron (const Array2<Complex>&, const Array2<Complex>&, Array2<Complex>&);
 
 DEFUN_DLD (kron, args,  nargout, "-*- texinfo -*-\n\
-@deftypefn {Function File} {} kron (@var{a}, @var{b})\n\
+@deftypefn {Loadable Function} {} kron (@var{a}, @var{b})\n\
 Form the kronecker product of two matrices, defined block by block as\n\
 \n\
 @example\n\
@@ -96,7 +95,7 @@ kron (1:4, ones (3, 1))\n\
 
   if (nargin != 2 || nargout > 1)
     {
-      print_usage ("kron");
+      print_usage ();
     }
   else if (args(0).is_complex_type () || args(1).is_complex_type ())
     {
