@@ -1,11 +1,13 @@
 /*
 
-Copyright (C) 2005 David Bateman
+Copyright (C) 2005, 2006, 2007 David Bateman
+
+This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -13,9 +15,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; see the file COPYING.  If not, write to the
-Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-Boston, MA 02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -54,7 +55,7 @@ positions as in the matrix @var{a}.\n\
 Alternatively, the fill-in of the incomplete LU factorization can\n\
 be controlled through the variable @var{droptol} or the structure\n\
 @var{opts}. The UMFPACK multifrontal factorization code by Tim A.\n\
-Davis is used for the incomplete LU factorication, (availability\n\
+Davis is used for the incomplete LU factorization, (availability\n\
 @url{http://www.cise.ufl.edu/research/sparse/umfpack/})\n\
 \n\
 @var{droptol} determines the values below which the values in the LU\n\
@@ -74,7 +75,7 @@ then this is equivalent to using the variable @var{droptol}.\n\
 @item milu\n\
 A logical variable flagging whether to use the modified incomplete LU\n\
 factorization. In the case that @code{milu} is true, the dropped values\n\
-are subtract from the diagonal of the matrix U of the factorization.\n\
+are subtracted from the diagonal of the matrix U of the factorization.\n\
 The default is @code{false}.\n\
 \n\
 @item udiag\n\
@@ -299,7 +300,7 @@ are the same as for @dfn{lu}.\n\
 
 /*
 
-%!test
+%!testif HAVE_UMFPACK
 %! a=sparse([1,2,0,0;0,1,2,0;1e-14,0,3,0;0,0,0,1]);
 %! [l,u]=luinc(a,1e-10);
 %! assert(l*u, sparse([1,2,0,0;0,1,2,0;0,0,3,0;0,0,0,1]),1e-10);
@@ -307,7 +308,7 @@ are the same as for @dfn{lu}.\n\
 %! [l,u]=luinc(a,opts);
 %! assert(l*u, sparse([1,2,0,0;0,1,2,0;0,0,3,0;0,0,0,1]),1e-10);
 
-%!test
+%!testif HAVE_UMFPACK
 %! a=sparse([1i,2,0,0;0,1,2,0;1e-14,0,3,0;0,0,0,1]);
 %! [l,u]=luinc(a,1e-10);
 %! assert(l*u, sparse([1i,2,0,0;0,1,2,0;0,0,3,0;0,0,0,1]),1e-10);
