@@ -1,13 +1,14 @@
 /*
 
-Copyright (C) 1996, 1997 John W. Eaton
+Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
+              2002, 2003, 2004, 2005, 2006, 2007 John W. Eaton
 
 This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -15,9 +16,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -32,7 +32,7 @@ Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 //   sync_system   (now merged with system)
 //   async_system  (now merged with system)
 
-// Completely rewritten by John W. Eaton <jwe@bevo.che.wics.edu>,
+// Extensively revised by John W. Eaton <jwe@bevo.che.wics.edu>,
 // April 1996.
 
 #ifdef HAVE_CONFIG_H
@@ -59,9 +59,13 @@ Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 
 #include "error.h"
 #include "file-ops.h"
+#include "file-stat.h"
 #include "lo-ieee.h"
+#include "oct-env.h"
 
 #include "defun.h"
+#include "file-io.h"
+#include "load-path.h"
 #include "oct-fstrm.h"
 #include "oct-iostrm.h"
 #include "oct-map.h"
@@ -108,7 +112,7 @@ close_files (void)
 
 // List of files to delete when we exit or crash.
 //
-// XXX FIXME XXX -- this should really be static, but that causes
+// FIXME -- this should really be static, but that causes
 // problems on some systems.
 std::stack <std::string> tmp_files;
 
@@ -140,7 +144,27 @@ fopen_mode_to_ios_mode (const std::string& mode_arg)
 
       std::string mode = mode_arg;
 
-      size_t pos = mode.find ('z');
+      // 'W' and 'R' are accepted as 'w' and 'r', but we warn about
+      // them because Matlab says they perform "automatic flushing"
+      // but we don't know precisely what action that implies.
+
+      size_t pos = mode.find ('W');
+
+      if (pos != NPOS)
+	{
+	  warning ("fopen: treating mode \"W\" as equivalent to \"w\"");
+	  mode[pos] = 'w';
+	}
+
+      pos = mode.find ('R');
+
+      if (pos != NPOS)
+	{
+	  warning ("fopen: treating mode \"R\" as equivalent to \"r\"");
+	  mode[pos] = 'r';
+	}
+
+      pos = mode.find ('z');
 
       if (pos != NPOS)
 	{
@@ -164,7 +188,7 @@ fopen_mode_to_ios_mode (const std::string& mode_arg)
 	  else if (mode == "w+t")
 	    retval = std::ios::in | std::ios::out | std::ios::trunc;
 	  else if (mode == "a+t")
-	    retval = std::ios::in | std::ios::out | std::ios::ate;
+	    retval = std::ios::in | std::ios::out | std::ios::app;
 	  else if (mode == "rb" || mode == "r")
 	    retval = std::ios::in | std::ios::binary;
 	  else if (mode == "wb" || mode == "w")
@@ -177,7 +201,7 @@ fopen_mode_to_ios_mode (const std::string& mode_arg)
 	    retval = (std::ios::in | std::ios::out | std::ios::trunc
 		      | std::ios::binary);
 	  else if (mode == "a+b" || mode == "a+")
-	    retval = (std::ios::in | std::ios::out | std::ios::ate
+	    retval = (std::ios::in | std::ios::out | std::ios::app
 		      | std::ios::binary);
 	  else
 	    ::error ("invalid mode specified");
@@ -192,8 +216,8 @@ DEFUN (fclose, args, ,
 @deftypefn {Built-in Function} {} fclose (@var{fid})\n\
 Closes the specified file.  If successful, @code{fclose} returns 0,\n\
 otherwise, it returns -1.\n\
-@end deftypefn\n\
-@seealso{fopen, fseek, ftell}")
+@seealso{fopen, fseek, ftell}\n\
+@end deftypefn")
 {
   octave_value retval = -1;
 
@@ -202,7 +226,7 @@ otherwise, it returns -1.\n\
   if (nargin == 1)
     retval = octave_stream_list::remove (args(0), "fclose");
   else
-    print_usage ("fclose");
+    print_usage ();
 
   return retval;
 }
@@ -227,7 +251,7 @@ Clear the stream state for the specified file.\n\
 	os.clearerr ();
     }
   else
-    print_usage ("fclear");
+    print_usage ();
 
   return retval;
 }
@@ -242,8 +266,8 @@ stream before calling @code{input}.\n\
 \n\
 @code{fflush} returns 0 on success and an OS dependent error value\n\
 (@minus{}1 on unix) on error.\n\
-@end deftypefn\n\
-@seealso{fopen, fclose}")
+@seealso{fopen, fclose}\n\
+@end deftypefn")
 {
   octave_value retval = -1;
 
@@ -251,7 +275,7 @@ stream before calling @code{input}.\n\
 
   if (nargin == 1)
     {
-      // XXX FIXME XXX -- any way to avoid special case for stdout?
+      // FIXME -- any way to avoid special case for stdout?
 
       int fid = octave_stream_list::get_file_number (args (0));
 
@@ -270,7 +294,7 @@ stream before calling @code{input}.\n\
 	}
     }
   else
-    print_usage ("fflush");
+    print_usage ();
 
   return retval;
 }
@@ -286,8 +310,8 @@ If @var{len} is omitted, @code{fgetl} reads until the next newline\n\
 character.\n\
 \n\
 If there are no more characters to read, @code{fgetl} returns @minus{}1.\n\
-@end deftypefn\n\
-@seealso{fread, fscanf}")
+@seealso{fread, fscanf}\n\
+@end deftypefn")
 {
   static std::string who = "fgetl";
 
@@ -304,8 +328,7 @@ If there are no more characters to read, @code{fgetl} returns @minus{}1.\n\
 
       if (! error_state)
 	{
-	  octave_value len_arg = (nargin == 2)
-	    ? args(1) : octave_value (INT_MAX);
+	  octave_value len_arg = (nargin == 2) ? args(1) : octave_value ();
 
 	  bool err = false;
 
@@ -319,7 +342,7 @@ If there are no more characters to read, @code{fgetl} returns @minus{}1.\n\
 	}
     }
   else
-    print_usage (who);
+    print_usage ();
 
   return retval;
 }
@@ -335,8 +358,8 @@ If @var{len} is omitted, @code{fgets} reads until the next newline\n\
 character.\n\
 \n\
 If there are no more characters to read, @code{fgets} returns @minus{}1.\n\
-@end deftypefn\n\
-@seealso{fread, fscanf}")
+@seealso{fread, fscanf}\n\
+@end deftypefn")
 {
   static std::string who = "fgets";
 
@@ -353,8 +376,7 @@ If there are no more characters to read, @code{fgets} returns @minus{}1.\n\
 
       if (! error_state)
 	{
-	  octave_value len_arg = (nargin == 2)
-	    ? args(1) : octave_value (INT_MAX);
+	  octave_value len_arg = (nargin == 2) ? args(1) : octave_value ();
 
 	  bool err = false;
 
@@ -368,7 +390,7 @@ If there are no more characters to read, @code{fgets} returns @minus{}1.\n\
 	}
     }
   else
-    print_usage (who);
+    print_usage ();
 
   return retval;
 }
@@ -390,19 +412,50 @@ do_stream_open (const std::string& name, const std::string& mode,
 
       if (! error_state)
 	{
-#if defined (HAVE_ZLIB)
+	  std::string fname = file_ops::tilde_expand (name);
+
+	  if (! (md & std::ios::out
+		 || octave_env::absolute_pathname (fname)
+		 || octave_env::rooted_relative_pathname (fname)))
+	    {
+	      file_stat fs (fname);
+
+	      if (! fs.exists ())
+		{
+		  std::string tmp = octave_env::make_absolute
+		    (load_path::find_file (fname), octave_env::getcwd ());
+
+		  if (! tmp.empty ())
+		    {
+		      warning_with_id ("Octave:fopen-file-in-path",
+				       "fopen: file found in load path");
+		      fname = tmp;
+		    }
+		}
+	    }
+
 	  std::string tmode = mode;
 
+	  // Use binary mode if 't' is not specified, but don't add
+	  // 'b' if it is already present.
+
+	  size_t bpos = tmode.find ('b');
+	  size_t tpos = tmode.find ('t');
+
+	  if (bpos == NPOS && tpos == NPOS)
+	    tmode += 'b';
+
+#if defined (HAVE_ZLIB)
 	  size_t pos = tmode.find ('z');
 
 	  if (pos != NPOS)
 	    {
 	      tmode.erase (pos, 1);
 
-	      gzFile fptr = ::gzopen (name.c_str (), tmode.c_str ());
+	      gzFile fptr = ::gzopen (fname.c_str (), tmode.c_str ());
 
 	      if (fptr)
-		retval = octave_zstdiostream::create (name, fptr, md, flt_fmt);
+		retval = octave_zstdiostream::create (fname, fptr, md, flt_fmt);
 	      else
 		{
 		  using namespace std;
@@ -412,11 +465,11 @@ do_stream_open (const std::string& name, const std::string& mode,
 	  else
 #endif
 	    {
-	      FILE *fptr = ::fopen (name.c_str (), mode.c_str ());
+	      FILE *fptr = ::fopen (fname.c_str (), tmode.c_str ());
 
-	      if (fptr)
-		retval = octave_stdiostream::create (name, fptr, md, flt_fmt);
-	      else
+	      retval = octave_stdiostream::create (fname, fptr, md, flt_fmt);
+
+	      if (! fptr)
 		{
 		  using namespace std;
 		  retval.error (::strerror (errno));
@@ -506,7 +559,7 @@ The possible values @samp{mode} may have are\n\
 Open a file for reading.\n\
 \n\
 @item @samp{w}\n\
-Open a file for writing.  The previous contents are discared.\n\
+Open a file for writing.  The previous contents are discarded.\n\
 \n\
 @item @samp{a}\n\
 Open or create a file for writing at the end of the file.\n\
@@ -527,7 +580,7 @@ Append a \"t\" to the mode string to open the file in text mode or a\n\
 \"b\" to open in binary mode.  On Windows and Macintosh systems, text\n\
 mode reading and writing automatically converts linefeeds to the\n\
 appropriate line end character for the system (carriage-return linefeed\n\
-on Windows, carriage-returnn on Macintosh).  The default if no mode is\n\
+on Windows, carriage-return on Macintosh).  The default if no mode is\n\
 specified is binary mode.\n\
 \n\
 Additionally, you may append a \"z\" to the mode string to open a\n\
@@ -560,8 +613,8 @@ Cray floating format.\n\
 @noindent\n\
 however, conversions are currently only supported for @samp{native}\n\
 @samp{ieee-be}, and @samp{ieee-le} formats.\n\
-@end deftypefn\n\
-@seealso{fclose, fread, fseek}")
+@seealso{fclose, fread, fseek}\n\
+@end deftypefn")
 {
   octave_value_list retval;
 
@@ -608,26 +661,21 @@ however, conversions are currently only supported for @samp{native}\n\
 
       octave_stream os = do_stream_open (args(0), mode, arch, "fopen", fid);
 
-      if (os.is_valid ())
+      if (os && ! error_state)
 	{
-	  if (os && ! error_state)
-	    {
-	      retval(1) = "";
-	      retval(0) = octave_stream_list::insert (os);
-	    }
-	  else
-	    {
-	      int error_number = 0;
-
-	      retval(1) = os.error (false, error_number);
-	      retval(0) = -1.0;
-	    }
+	  retval(1) = "";
+	  retval(0) = octave_stream_list::insert (os);
 	}
       else
-	error ("fopen: internal error");
+	{
+	  int error_number = 0;
+
+	  retval(1) = os.error (false, error_number);
+	  retval(0) = -1.0;
+	}
     }
   else
-    print_usage ("fopen");
+    print_usage ();
 
   return retval;
 }
@@ -686,7 +734,7 @@ Move the file pointer to the beginning of the file @var{fid}, returning\n\
 	result = os.rewind ();
     }
   else
-    print_usage ("frewind");
+    print_usage ();
 
   if (nargout > 0)
     retval = result;
@@ -704,11 +752,11 @@ which may be one of the predefined variables @code{SEEK_CUR} (current\n\
 position), @code{SEEK_SET} (beginning), or @code{SEEK_END} (end of\n\
 file) or strings \"cof\", \"bof\" or \"eof\". If @var{origin} is omitted,\n\
 @code{SEEK_SET} is assumed.  The offset must be zero, or a value returned\n\
-by @code{ftell} (in which case @var{origin} must be @code{SEEK_SET}.\n\
+by @code{ftell} (in which case @var{origin} must be @code{SEEK_SET}).\n\
 \n\
 Return 0 on success and -1 on error.\n\
-@end deftypefn\n\
-@seealso{ftell, fopen, fclose}")
+@seealso{ftell, fopen, fclose}\n\
+@end deftypefn")
 {
   octave_value retval = -1;
 
@@ -727,7 +775,7 @@ Return 0 on success and -1 on error.\n\
 	}
     }
   else
-    print_usage ("fseek");
+    print_usage ();
 
   return retval;
 }
@@ -737,8 +785,8 @@ DEFUN (ftell, args, ,
 @deftypefn {Built-in Function} {} ftell (@var{fid})\n\
 Return the position of the file pointer as the number of characters\n\
 from the beginning of the file @var{fid}.\n\
-@end deftypefn\n\
-@seealso{fseek, fopen, fclose}")
+@seealso{fseek, fopen, fclose}\n\
+@end deftypefn")
 {
   octave_value retval = -1;
 
@@ -752,7 +800,7 @@ from the beginning of the file @var{fid}.\n\
 	retval = os.tell ();
     }
   else
-    print_usage ("ftell");
+    print_usage ();
 
   return retval;
 }
@@ -762,8 +810,8 @@ DEFUN (fprintf, args, nargout,
 @deftypefn {Built-in Function} {} fprintf (@var{fid}, @var{template}, @dots{})\n\
 This function is just like @code{printf}, except that the output is\n\
 written to the stream @var{fid} instead of @code{stdout}.\n\
-@end deftypefn\n\
-@seealso{printf, sprintf, fread, fscanf, fopen, fclose}")
+@seealso{printf, sprintf, fread, fscanf, fopen, fclose}\n\
+@end deftypefn")
 {
   static std::string who = "fprintf";
 
@@ -809,7 +857,7 @@ written to the stream @var{fid} instead of @code{stdout}.\n\
 	}
     }
   else
-    print_usage (who);
+    print_usage ();
 
   if (nargout > 0)
     retval = result;
@@ -821,11 +869,15 @@ DEFUN (printf, args, nargout,
   "-*- texinfo -*-\n\
 @deftypefn {Built-in Function} {} printf (@var{template}, @dots{})\n\
 Print optional arguments under the control of the template string\n\
-@var{template} to the stream @code{stdout}.\n\
+@var{template} to the stream @code{stdout} and return the number of\n\
+characters printed.\n\
+@ifclear OCTAVE_MANUAL\n\
 \n\
-Return the number of characters printed.\n\
-@end deftypefn\n\
-@seealso{fprintf, sprintf, scanf}")
+See the Formatted Output section of the GNU Octave manual for a\n\
+complete description of the syntax of the template string.\n\
+@end ifclear\n\
+@seealso{fprintf, sprintf, scanf}\n\
+@end deftypefn")
 {
   static std::string who = "printf";
 
@@ -855,7 +907,7 @@ Return the number of characters printed.\n\
 	::error ("%s: format must be a string", who.c_str ());
     }
   else
-    print_usage (who);
+    print_usage ();
 
   if (nargout > 0)
     retval = result;
@@ -885,7 +937,7 @@ Return a non-negative number on success and EOF on error.\n\
 	retval = os.puts (args(1), who);
     }
   else
-    print_usage (who);
+    print_usage ();
 
   return retval;
 }
@@ -905,7 +957,7 @@ Return a non-negative number on success and EOF on error.\n\
   if (args.length () == 1)
     retval = stdout_stream.puts (args(0), who);
   else
-    print_usage (who);
+    print_usage ();
 
   return retval;
 }
@@ -918,8 +970,8 @@ string.  Unlike the C library function, which requires you to provide a\n\
 suitably sized string as an argument, Octave's @code{sprintf} function\n\
 returns the string, automatically sized to hold all of the items\n\
 converted.\n\
-@end deftypefn\n\
-@seealso{printf, fprintf, sscanf}")
+@seealso{printf, fprintf, sscanf}\n\
+@end deftypefn")
 {
   static std::string who = "sprintf";
 
@@ -939,7 +991,9 @@ converted.\n\
 
       if (os.is_valid ())
 	{
-	  if (args(0).is_string ())
+	  octave_value fmt_arg = args(0);
+
+	  if (fmt_arg.is_string ())
 	    {
 	      octave_value_list tmp_args;
 
@@ -951,9 +1005,10 @@ converted.\n\
 		    tmp_args(i-1) = args(i);
 		}
 
-	      retval(2) = os.printf (args(0), tmp_args, who);
+	      retval(2) = os.printf (fmt_arg, tmp_args, who);
 	      retval(1) = os.error ();
-	      retval(0) = ostr->str ();
+	      retval(0) = octave_value (ostr->str (),
+					fmt_arg.is_sq_string () ? '\'' : '"');
 	    }
 	  else
 	    ::error ("%s: format must be a string", who.c_str ());
@@ -962,7 +1017,7 @@ converted.\n\
 	::error ("%s: unable to create output buffer", who.c_str ());
     }
   else
-    print_usage (who);
+    print_usage ();
 
   return retval;
 }
@@ -1008,8 +1063,13 @@ with each conversion specifier in @var{template} corresponding to a\n\
 single scalar return value.  This form is more `C-like', and also\n\
 compatible with previous versions of Octave.  The number of successful\n\
 conversions is returned in @var{count}\n\
-@end deftypefn\n\
-@seealso{scanf, sscanf, fread, fprintf}")
+@ifclear OCTAVE_MANUAL\n\
+\n\
+See the Formatted Input section of the GNU Octave manual for a\n\
+complete description of the syntax of the template string.\n\
+@end ifclear\n\
+@seealso{scanf, sscanf, fread, fprintf}\n\
+@end deftypefn")
 {
   static std::string who = "fscanf";
 
@@ -1061,7 +1121,7 @@ conversions is returned in @var{count}\n\
 	    }
 	}
       else
-	print_usage (who);
+	print_usage ();
     }
 
   return retval;
@@ -1074,8 +1134,8 @@ DEFUN (sscanf, args, ,
 This is like @code{fscanf}, except that the characters are taken from the\n\
 string @var{string} instead of from a stream.  Reaching the end of the\n\
 string is treated as an end-of-file condition.\n\
-@end deftypefn\n\
-@seealso{fscanf, scanf, sprintf}")
+@seealso{fscanf, scanf, sprintf}\n\
+@end deftypefn")
 {
   static std::string who = "sscanf";
 
@@ -1132,7 +1192,7 @@ string is treated as an end-of-file condition.\n\
 
 		      octave_value tmp = os.scanf (args(1), size, count, who);
 
-		      // XXX FIXME XXX -- is this the right thing to do?
+		      // FIXME -- is this the right thing to do?
 		      // Extract error message first, because getting
 		      // position will clear it.
 		      std::string errmsg = os.error ();
@@ -1153,7 +1213,7 @@ string is treated as an end-of-file condition.\n\
 	    ::error ("%s: first argument must be a string", who.c_str ());
 	}
       else
-	print_usage (who);
+	print_usage ();
     }
 
   return retval;
@@ -1167,8 +1227,8 @@ This is equivalent to calling @code{fscanf} with @var{fid} = @code{stdin}.\n\
 \n\
 It is currently not useful to call @code{scanf} in interactive\n\
 programs.\n\
-@end deftypefn\n\
-@seealso{fscanf, sscanf, printf}")
+@seealso{fscanf, sscanf, printf}\n\
+@end deftypefn")
 {
   int nargin = args.length ();
 
@@ -1364,10 +1424,11 @@ integer values and return an array of 32-bit integer values.  By\n\
 default, @code{fread} returns a double precision array.  The special\n\
 form @samp{*TYPE} is shorthand for @samp{TYPE=>TYPE}.\n\
 \n\
-The conversion and repeat counts may be combined.  For example,\n\
-@samp{32*single=>single} causes @code{fread} to read blocks of single\n\
-precision floating point values and return an array of single precision\n\
-values instead of the default array of double precision values.\n\
+The conversion and repeat counts may be combined.  For example, the\n\
+specification @samp{32*single=>single} causes @code{fread} to read\n\
+blocks of single precision floating point values and return an array\n\
+of single precision values instead of the default array of double\n\
+precision values.\n\
 \n\
 The optional argument @var{skip} specifies the number of bytes to skip\n\
 after each element (or block of elements) is read.  If it is not\n\
@@ -1411,8 +1472,8 @@ Conversions are currently only supported for @code{\"ieee-be\"} and\n\
 \n\
 The data read from the file is returned in @var{val}, and the number of\n\
 values read is returned in @code{count}\n\
-@end deftypefn\n\
-@seealso{fwrite, fopen, fclose}")
+@seealso{fwrite, fopen, fclose}\n\
+@end deftypefn")
 {
   octave_value_list retval;
 
@@ -1455,7 +1516,7 @@ values read is returned in @code{count}\n\
 	}
     }
   else
-    print_usage ("fread");
+    print_usage ();
 
   return retval;
 }
@@ -1523,8 +1584,8 @@ optional, and are interpreted as described for @code{fread}.\n\
 \n\
 The behavior of @code{fwrite} is undefined if the values in @var{data}\n\
 are too large to fit in the specified precision.\n\
-@end deftypefn\n\
-@seealso{fread, fopen, fclose}")
+@seealso{fread, fopen, fclose}\n\
+@end deftypefn")
 {
   octave_value retval = -1;
 
@@ -1553,20 +1614,20 @@ are too large to fit in the specified precision.\n\
 	}
     }
   else
-    print_usage ("fwrite");
+    print_usage ();
 
   return retval;
 }
 
-DEFUN (feof, args, ,
+DEFUNX ("feof", Ffeof, args, ,
   "-*- texinfo -*-\n\
 @deftypefn {Built-in Function} {} feof (@var{fid})\n\
 Return 1 if an end-of-file condition has been encountered for a given\n\
 file and 0 otherwise.  Note that it will only return 1 if the end of the\n\
 file has already been encountered, not if the next read operation will\n\
 result in an end-of-file condition.\n\
-@end deftypefn\n\
-@seealso{fread, fopen, fclose}")
+@seealso{fread, fopen, fclose}\n\
+@end deftypefn")
 {
   octave_value retval = -1;
 
@@ -1580,12 +1641,12 @@ result in an end-of-file condition.\n\
 	retval = os.eof () ? 1.0 : 0.0;
     }
   else
-    print_usage ("feof");
+    print_usage ();
 
   return retval;
 }
 
-DEFUN (ferror, args, ,
+DEFUNX ("ferror", Fferror, args, ,
   "-*- texinfo -*-\n\
 @deftypefn {Built-in Function} {} ferror (@var{fid})\n\
 Return 1 if an error condition has been encountered for a given file\n\
@@ -1625,7 +1686,7 @@ error condition.\n\
 	}
     }
   else
-    print_usage ("ferror");
+    print_usage ();
 
   return retval;
 }
@@ -1699,7 +1760,7 @@ endwhile\n\
 	::error ("popen: name must be a string");
     }
   else
-    print_usage ("popen");
+    print_usage ();
 
   return retval;
 }
@@ -1718,7 +1779,7 @@ use @code{fclose} for the same purpose.\n\
   if (nargin == 1)
     retval = octave_stream_list::remove (args(0), "pclose");
   else
-    print_usage ("pclose");
+    print_usage ();
 
   return retval;
 }
@@ -1734,8 +1795,8 @@ is used.  If @var{dir} is provided, it must exist, otherwise the default\n\
 directory for temporary files is used.  Since the named file is not\n\
 opened, by @code{tmpnam}, it is possible (though relatively unlikely)\n\
 that it will not be available by the time your program attempts to open it.\n\
-@end deftypefn\n\
-@seealso{tmpfile, mkstemp, P_tmpdir}")
+@seealso{tmpfile, mkstemp, P_tmpdir}\n\
+@end deftypefn")
 {
   octave_value retval;
 
@@ -1759,7 +1820,7 @@ that it will not be available by the time your program attempts to open it.\n\
 	::error ("expecting first argument to be a string");
     }
   else
-    print_usage ("tmpnam");
+    print_usage ();
 
   return retval;
 }
@@ -1777,8 +1838,8 @@ exits.\n\
 If successful, @var{fid} is a valid file ID and @var{msg} is an empty\n\
 string.  Otherwise, @var{fid} is -1 and @var{msg} contains a\n\
 system-dependent error message.\n\
-@end deftypefn\n\
-@seealso{tmpnam, mkstemp, P_tmpdir}")
+@seealso{tmpnam, mkstemp, P_tmpdir}\n\
+@end deftypefn")
 {
   octave_value_list retval;
 
@@ -1813,7 +1874,7 @@ system-dependent error message.\n\
 	}
     }
   else
-    print_usage ("tmpfile");
+    print_usage ();
 
   return retval;
 }
@@ -1834,11 +1895,11 @@ the file will be deleted automatically when Octave exits, or when\n\
 the function @code{purge_tmp_files} is called.\n\
 \n\
 If successful, @var{fid} is a valid file ID, @var{name} is the name of\n\
-the file, and and @var{msg} is an empty string.  Otherwise, @var{fid}\n\
+the file, and @var{msg} is an empty string.  Otherwise, @var{fid}\n\
 is -1, @var{name} is empty, and @var{msg} contains a system-dependent\n\
 error message.\n\
-@end deftypefn\n\
-@seealso{tmpfile, tmpnam, P_tmpdir}")
+@seealso{tmpfile, tmpnam, P_tmpdir}\n\
+@end deftypefn")
 {
   octave_value_list retval;
 
@@ -1886,7 +1947,7 @@ error message.\n\
 		      retval(1) = nm;
 		      retval(0) = octave_stream_list::insert (s);
 
-		      if (nargin == 2)
+		      if (nargin == 2 && args(1).is_true ())
 			mark_for_deletion (nm);
 		    }
 		  else
@@ -1904,7 +1965,7 @@ error message.\n\
 	error ("mkstemp: expecting string as first argument");
     }
   else
-    print_usage ("mkstemp");
+    print_usage ();
 
 #else
   retval(2) = "mkstemp: not supported on this sytem";
@@ -1981,7 +2042,7 @@ interpreted as an octal number); otherwise an error message is printed.\n\
 	}
     }
   else
-    print_usage ("umask");
+    print_usage ();
 
   if (status >= 0)
     retval(0) = status;
@@ -1989,31 +2050,54 @@ interpreted as an octal number); otherwise an error message is printed.\n\
   return retval;
 }
 
-void
-symbols_of_file_io (void)
+static octave_value
+const_value (const char *, const octave_value_list& args, int val)
 {
+  octave_value retval;
+
+  int nargin = args.length ();
+
+  if (nargin == 0)
+    retval = val;
+  else
+    print_usage ();
+
+  return retval;
+}
+
 #if ! defined (P_tmpdir)
 #define P_tmpdir "/tmp"
 #endif
 
-  DEFCONSTX ("P_tmpdir", SBV_P_tmpdir, P_tmpdir,
-    "-*- texinfo -*-\n\
-@defvr {Built-in Constant} P_tmpdir\n\
-The default name of the directory for temporary files on this system.\n\
-The value of this variable is system dependent.\n\
-@end defvr");
+DEFUNX ("P_tmpdir", FP_tmpdir, args, ,
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} P_tmpdir ()\n\
+Return the default name of the directory for temporary files on\n\
+this system.  The name of this directory is system dependent.\n\
+@end deftypefn")
+{
+  octave_value retval;
 
-  // NOTE: the values of SEEK_SET, SEEK_CUR, and SEEK_END have to be
-  // this way for Matlab compatibility.
+  int nargin = args.length ();
 
-  DEFCONSTX ("SEEK_SET", SBV_SEEK_SET, -1,
-    "-*- texinfo -*-\n\
-@defvr {Built-in Constant} SEEK_SET\n\
-@defvrx {Built-in Constant} SEEK_CUR\n\
-@defvrx {Built-in Constant} SEEK_END\n\
-These variables may be used as the optional third argument for the\n\
-function @code{fseek}.\n\
-\n\
+  if (nargin == 0)
+    retval = P_tmpdir;
+  else
+    print_usage ();
+
+  return retval;
+}
+
+// NOTE: the values of SEEK_SET, SEEK_CUR, and SEEK_END have to be
+// this way for Matlab compatibility.
+
+DEFUNX ("SEEK_SET", FSEEK_SET, args, ,
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} SEEK_SET ()\n\
+@deftypefnx {Built-in Function} {} SEEK_CUR ()\n\
+@deftypefnx {Built-in Function} {} SEEK_END ()\n\
+Return the value required to request that @code{fseek} perform\n\
+one of the following actions:\n\
 @table @code\n\
 @item SEEK_SET\n\
 Position file relative to the beginning.\n\
@@ -2022,48 +2106,80 @@ Position file relative to the beginning.\n\
 Position file relative to the current position.\n\
 \n\
 @item SEEK_END\n\
-used with fseek to position file relative to the end.\n\
+Position file relative to the end.\n\
 @end table\n\
-@end defvr");
+@end deftypefn")
+{
+  return const_value ("SEEK_SET", args, -1);
+}
 
-  DEFCONSTX ("SEEK_CUR", SBV_SEEK_CUR, 0,
-    "-*- texinfo -*-\n\
-@defvr {Built-in Constant} SEEK_CUR\n\
+DEFUNX ("SEEK_CUR", FSEEK_CUR, args, ,
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} SEEK_CUR ()\n\
 See SEEK_SET.\n\
-@end defvr");
+@end deftypefn")
+{
+  return const_value ("SEEK_CUR", args, 0);
+}
 
-  DEFCONSTX ("SEEK_END", SBV_SEEK_END, 1,
-    "-*- texinfo -*-\n\
-@defvr {Built-in Constant} SEEK_END\n\
+DEFUNX ("SEEK_END", FSEEK_END, args, ,
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} SEEK_END ()\n\
 See SEEK_SET.\n\
-@end defvr");
+@end deftypefn")
+{
+  return const_value ("SEEK_END", args, 1);
+}
 
-  DEFCONSTX ("stdin", SBV_stdin, stdin_file,
-    "-*- texinfo -*-\n\
-@defvr {Built-in Constant} stdin\n\
-The standard input stream (file id 0).  When Octave is used\n\
-interactively, this is filtered through the command line editing\n\
-functions.\n\
+static octave_value
+const_value (const char *, const octave_value_list& args,
+	     const octave_value& val)
+{
+  octave_value retval;
+
+  int nargin = args.length ();
+
+  if (nargin == 0)
+    retval = val;
+  else
+    print_usage ();
+
+  return retval;
+}
+
+DEFUNX ("stdin", Fstdin, args, ,
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} stdin ()\n\
+Return the numeric value corresponding to the standard input stream.\n\
+When Octave is used interactively, this is filtered through the command\n\
+line editing functions.\n\
 @seealso{stdout, stderr}\n\
-@end defvr");
+@end deftypefn")
+{
+  return const_value ("stdin", args, stdin_file);
+}
 
-  DEFCONSTX ("stdout", SBV_stdout, stdout_file,
-    "-*- texinfo -*-\n\
-@defvr {Built-in Constant} stdout\n\
-The standard output stream (file id 1).  Data written to the\n\
-standard output is normally filtered through the pager.\n\
+DEFUNX ("stdout", Fstdout, args, ,
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} stdout ()\n\
+Return the numeric value corresponding to the standard output stream.\n\
+Data written to the standard output is normally filtered through the pager.\n\
 @seealso{stdin, stderr}\n\
-@end defvr");
+@end deftypefn")
+{
+  return const_value ("stdout", args, stdout_file);
+}
 
-  DEFCONSTX ("stderr", SBV_stderr, stderr_file,
-    "-*- texinfo -*-\n\
-@defvr {Built-in Constant} stderr\n\
-The standard error stream (file id 2).  Even if paging is turned on,\n\
-the standard error is not sent to the pager.  It is useful for error\n\
-messages and prompts.\n\
+DEFUNX ("stderr", Fstderr, args, ,
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} stderr ()\n\
+Return the numeric value corresponding to the standard error stream.\n\
+Even if paging is turned on, the standard error is not sent to the\n\
+pager.  It is useful for error messages and prompts.\n\
 @seealso{stdin, stdout}\n\
-@end defvr");
-
+@end deftypefn")
+{
+  return const_value ("stderr", args, stderr_file);
 }
 
 /*
